from django.apps import AppConfig
from django.apps.registry import apps


class Smev3Config(AppConfig):

    name = 'concentrator.smev3_v321'
    label = 'smev3_v321'
    verbose_name = 'СМЭВ 3'

    def ready(self):
        # Данные из контингента тянутся в сервисах смэв3
        if not apps.is_installed('kinder.plugins.contingent'):
            raise RuntimeError('Contingent plugin must be installed')
        # Иначе не видят таски
        import concentrator.smev3_v321.base.tasks
        import concentrator.smev3_v321.esnsi.tasks
        from concentrator.smev3_v321 import observer

        from .base.utils import SMEV3RepositoryExecutors
        from .application_request.helpers import ApplicationRequestExecutor
        from .get_application_admission_request.helpers import (
            GetApplicationAdmissionRequestExecutor)
        from .application_rejection_request.helpers import (
            ApplicationRejectionRequestExecutor)
        from concentrator.smev3_v321.get_application_queue.helpers import (
            GetApplicationQueueRequestExecutor
        )
        from concentrator.smev3_v321.get_application_request.helpers import (
            GetApplicationRequestExecutor)
        from .cancel_request.helpers import CancelRequestExecutor
        from .application_order_info_request.helpers import (
            ApplicationOrderInfoRequestExecutor)
        from .get_application_queue_reason_request.helpers import (
            GetApplicationQueueReasonRequestExecutor)
        from .application_admission_request.helpers import (
            ApplicationAdmissionRequestExecutor)
        
        from concentrator.change import StorageHelper
        from .application_request.changes import (
            Smev3DeclarationPrivilegeChangeHelper,
            Smev3DeclarationUnitChangeHelper,
            Smev3DeclarationDocsChangeHelper,
            Smev3DeclarationChangeHelper,
            Smev3DelegateChangeHelper,
            Smev3ChildrenChangeHelper,
        )

        config = [
            ApplicationRequestExecutor,
            GetApplicationAdmissionRequestExecutor,
            ApplicationRejectionRequestExecutor,
            GetApplicationQueueRequestExecutor,
            GetApplicationRequestExecutor,
            CancelRequestExecutor,
            ApplicationOrderInfoRequestExecutor,
            GetApplicationQueueReasonRequestExecutor,
            ApplicationAdmissionRequestExecutor,
        ]

        SMEV3RepositoryExecutors.set_up(config)

        StorageHelper.register_change_helper(
            'DeclarationPrivilege', Smev3DeclarationPrivilegeChangeHelper
        )
        StorageHelper.register_change_helper(
            'DeclarationUnit', Smev3DeclarationUnitChangeHelper
        )
        StorageHelper.register_change_helper(
            Smev3DeclarationDocsChangeHelper.NAME_MODEL,
            Smev3DeclarationDocsChangeHelper)
        StorageHelper.register_change_helper(
            'Declaration', Smev3DeclarationChangeHelper)
        StorageHelper.register_change_helper(
            'Delegate', Smev3DelegateChangeHelper)
        StorageHelper.register_change_helper(
            'Children', Smev3ChildrenChangeHelper)
